@@ -92,6 +92,24 @@ async def test_async_main_cli_action_init(monkeypatch):
     mock_init.assert_called_once()
 
 
+@pytest.mark.asyncio
+async def test_async_main_cli_action_chunks(monkeypatch):
+    mock_cli_args = MagicMock(
+        no_stderr=False, project_root=".", action=CliAction.chunks
+    )
+    monkeypatch.setattr(
+        "vectorcode.main.parse_cli_args", AsyncMock(return_value=mock_cli_args)
+    )
+    mock_chunks = AsyncMock(return_value=0)
+    monkeypatch.setattr("vectorcode.subcommands.chunks", mock_chunks)
+    monkeypatch.setattr("vectorcode.main.get_project_config", AsyncMock())
+    monkeypatch.setattr("vectorcode.common.try_server", AsyncMock(return_value=True))
+
+    return_code = await async_main()
+    assert return_code == 0
+    mock_chunks.assert_called_once()
+
+
 @pytest.mark.asyncio
 async def test_async_main_cli_action_version(monkeypatch, capsys):
     mock_cli_args = MagicMock(
